<?php 
if (!defined('DP_BASE_DIR')) {
	die('You should not access this file directly.');
}
### Copyright (c) 2004, The dotProject Development Team dotproject.net and sf.net/projects/dotproject ###
### All rights reserved. Released under GPL License. For further Information see LICENSE ###

### CONFIGURATION FILE AUTOMATICALLY GENERATED BY THE DOTPROJECT INSTALLER ###
### FOR INFORMATION ON MANUAL CONFIGURATION AND FOR DOCUMENTATION SEE ./includes/config-dist.php ###

$dPconfig['dbtype'] = 'mysqli';
$dPconfig['dbhost'] = '[[softdbhost]]';
$dPconfig['dbname'] = '[[softdb]]';
$dPconfig['dbprefix'] = '[[dbprefix]]';
$dPconfig['dbuser'] = '[[softdbuser]]';
$dPconfig['dbpass'] = '[[softdbpass]]';
$dPconfig['dbpersist'] = false;
$dPconfig['root_dir'] = $baseDir;
$dPconfig['base_url'] = $baseUrl;
?>